@@ -6,11 +6,13 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+from .granttype import GrantType
 from .responsemode import ResponseMode
 from .responsetype import ResponseType
 
 
 __all__: list[str] = [
+    'GrantType',
     'ResponseType',
     'ResponseMode'
 ]
\ No newline at end of file
