@@ -9,6 +9,7 @@
 from .order import Order
 from .picklist import Picklist
 from .purchaseorder import PurchaseOrder
+from .product import Product
 from .supplier import Supplier
 from .user import User
 from .warehouse import Warehouse
@@ -18,6 +19,7 @@ from .webhook import Webhook
 __all__: list[str] = [
     'Order',
     'Picklist',
+    'Product',
     'PurchaseOrder',
     'Supplier',
     'User',
