@@ -8,6 +8,9 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 import pydantic
 
+from headless.core import Reference
+from .product import Product
+
 
 class PicklistProduct(pydantic.BaseModel):
     idproduct: int
@@ -21,4 +24,7 @@ class PicklistProduct(pydantic.BaseModel):
     amount_picked: int
     price: float
     weight: int
-    stock_location: str
+    stock_location: str | None = None
+
+    # Our fields
+    product: Product = Reference(Product, 'idproduct')
